from tkinter import *
from tkinter import messagebox, ttk
# Specific imports for handling DoB input
from tkcalendar import Calendar  # Requires installation - pip install tkcalendar
from datetime import date, datetime

class RegistrationForm:
    def __init__(self, master):
        """Initialize registration form window."""
        self.master = master
        self.master.title("User registration form")  # Set window title

        # === 5b - Centering GUI in device screen ===
        # Set desired window size
        window_width = 400
        window_height = 400

        # Get screen dimensions
        screen_width = self.master.winfo_screenwidth()
        screen_height = self.master.winfo_screenheight()

        # Calculate position x, y to center window
        x = (screen_width // 2) - (window_width // 2)
        y = (screen_height // 2) - (window_height // 2)

        # Set geometry with calculated center coordinates
        self.master.geometry(f"{window_width}x{window_height}+{x}+{y}")
        self.master.resizable(True, True)

        # Create main frame to hold all form elements
        self.frame = ttk.Frame(master, padding="10")
        self.frame.pack(fill=BOTH, expand=True)

        # First name
        ttk.Label(self.frame, text="First name:").grid(row=0, column=0, sticky=E, padx=5, pady=5)
        self.first_name = StringVar()
        ttk.Entry(self.frame, textvariable=self.first_name, width=30).grid(row=0, column=1, padx=5, pady=5)

        # Last name
        ttk.Label(self.frame, text="Last name:").grid(row=1, column=0, sticky=E, padx=5, pady=5)
        self.surname = StringVar()
        ttk.Entry(self.frame, textvariable=self.surname, width=30).grid(row=1, column=1, padx=5, pady=5)

        # Gender
        ttk.Label(self.frame, text="Gender:").grid(row=2, column=0, sticky=E, padx=5, pady=5)
        self.gender = StringVar(value="Select")  # Default value
        # OptionMenu for gender selection
        gender_options = ["Male", "Female", "Other", "Prefer not to say"]
        OptionMenu(self.frame, self.gender, *gender_options).grid(row=2, column=1, padx=5, pady=5, sticky=W)


        # DoB, approach 1: using Calendar widget for input
        ttk.Label(self.frame, text="DoB:").grid(row=3, column=0, sticky=E, padx=5, pady=5)
        self.cal = Calendar(self.frame,
                            selectmode='day',
                            year=2000, month=1, day=1,
                            mindate=date(1900, 1, 1),
                            maxdate=date(2024, 12, 31),
                            date_pattern='dd/mm/yyyy')  # Date format
        self.cal.grid(row=3, column=1, padx=5, pady=5)

#        # DoB, approach 2: using Calendar widget for input
#        ttk.Label(self.frame, text="DoB (DD/MM/YYYY):").grid(row=3, column=0, sticky=E, padx=5, pady=5)
#        self.dob = StringVar()
#        ttk.Entry(self.frame, textvariable=self.dob, width=30).grid(row=3, column=1, padx=5, pady=5)


        # Register Button
        ttk.Button(self.frame, text="Register", command=self.register).grid(row=4, column=0, columnspan=2, pady=10)

    def register(self):
        # Use Calendar widget's get_date() method to retrieve selected date (approach 1)
        dob = self.cal.get_date()
#        # Manual date input with validation (approach 2)
#        dob_input = self.dob.get()
#        try:
#            # Attempt to parse the input with the required format
#            dob_parsed = datetime.strptime(dob_input, "%d/%m/%Y")
#            # Check if the year is within the valid range
#            if not (1900 <= dob_parsed.year <= 2024):
#                raise ValueError("Year must be between 1900 and 2024.")
#        except ValueError as e:
#            messagebox.showerror("Invalid Date", f"Please enter a valid date in DD/MM/YYYY format.\nError: {e}")
#            return

        # Validate required fields: First name, Last name and Gender
        if not (self.first_name.get().strip() and self.surname.get().strip())\
        or self.gender.get() == "Select":
            messagebox.showwarning("Incomplete form", "Please fill out all fields!")
            return  # Stop further processing if validation fails

        info = (f"First name: {self.first_name.get()}\n"
                f"Last name: {self.surname.get()}\n"
                f"Gender: {self.gender.get()}\n"
                f"DoB: {dob}")
        messagebox.showinfo("User registration info", info)

# Create and run application
if __name__ == "__main__":
    root = Tk()
    app = RegistrationForm(root)
    root.mainloop()